{
  lib,
  config,
  ...
}: let
  cfg = config.marleyos.services.dunst;
in {
  options.marleyos.services.dunst.enable = lib.mkEnableOption "dunst";

  config = lib.mkIf cfg.enable {
    services.dunst = {
      enable = true;

      iconTheme = with config.stylix.iconTheme; {
        name =
          if config.lib.stylix.colors.variant == "dark"
          then dark
          else light;
        inherit package;
      };

      settings = {
        global = with config.stylix.fonts; {
          monitor = 0;
          sort = "yes";
          idle_threshold = 120;
          font = "${monospace.name} ${toString sizes.popup}";
          markup = "full";
          show_age_threshold = 60;
          word_wrap = "yes";
          ignore_newline = "no";
          stack_duplicates = true;
          hide_duplicate_count = false;
          show_indicators = "yes";
          sticky_history = "yes";
          history_length = 20;
          browser = "${lib.getExe config.marleyos.apps.browser} --new-tab";
          always_run_script = true;
          title = "Dunst";
          class = "Dunst";
          mouse_left_click = "do_action";
          mouse_middle_click = "close_current";
          mouse_right_click = "close_all";
        };

        signed_on = {
          appname = "Pidgin";
          summary = "*signed on*";
          urgency = "low";
        };

        signed_off = {
          appname = "Pidgin";
          summary = "*signed off*";
          urgency = "low";
        };

        says = {
          appname = "Pidgin";
          summary = "*says*";
          urgency = "critical";
        };
      };
    };
  };
}
